@@ -35,6 +35,7 @@ class ArticleItem(scrapy.Item):
     crawl_comment = scrapy.Field()
     comment_total_count = scrapy.Field()
     err_msg = scrapy.Field()
+    content_type = scrapy.Field()
 
 
 class ArticleCommentItem(scrapy.Item):
@@ -67,7 +68,9 @@ class PaperItem(scrapy.Item):
     source_id = scrapy.Field()
     source_name = scrapy.Field()
     block_id = scrapy.Field()
-    title = scrapy.Field()
+    title_cn = scrapy.Field()
+    title_en = scrapy.Field()
+    paper_id = scrapy.Field()
     cover_url = scrapy.Field()
     oss_cover_url = scrapy.Field()
     publish_date = scrapy.Field()
@@ -84,6 +87,7 @@ class PaperItem(scrapy.Item):
     year = scrapy.Field()  # 年份
     quote = scrapy.Field()  # 引用
     publish_source = scrapy.Field()  # 发布来源
+    publish_source_url = scrapy.Field()  # 发布来源URL
     subject = scrapy.Field()  # 学科
     pages = scrapy.Field()  # 页数
     word_number = scrapy.Field()  # 字数
